:mod:`npdl.objectives`
======================

.. automodule:: npdl.objectives


Objectives
----------

.. autosummary::
    :nosignatures:

    MeanSquaredError
    MSE
    HellingerDistance
    HeD
    BinaryCrossEntropy
    BCE
    SoftmaxCategoricalCrossEntropy
    SCCE


Detailed Description
--------------------

.. autoclass:: Objective
   :members:

.. autoclass:: MeanSquaredError
   :members:

.. autoclass:: MSE
   :members:

.. autoclass:: HellingerDistance
   :members:

.. autoclass:: HeD
   :members:

.. autoclass:: BinaryCrossEntropy
   :members:

.. autoclass:: BCE
   :members:

.. autoclass:: SoftmaxCategoricalCrossEntropy
   :members:

.. autoclass:: SCCE
   :members:
